import java.util.ArrayList;
import java.util.List;
import java.util.Iterator;

/**
 * Een eenvoudig model van een e-mailserver. De server kan 
 * berichten ontvangen (en slaat ze op). Hij kan die berichten
 * dan later doorsturen naar de e-mailclients wanneer ze erom
 * vragen.
 * 
 * @author David J. Barnes and Michael Kölling
 * @version 2011.07.31
 */
public class MailServer
{
    // Lijst met alle berichten
    private List<MailItem> items;

    /**
     * Creëer een mail-server
     */
    public MailServer()
    {
        items = new ArrayList<MailItem>();
    }

    /**
     * Hoeveel ongelezen berichten heeft een bepaalde gebruiker?
     * @param who De betreffende gebruiker
     * @return Het aantal ongelezen berichten
     */
    public int howManyMailItems(String who)
    {
        int count = 0;
        for(MailItem item : items) {
            if(item.getTo().equals(who)) {
                count++;
            }
        }
        return count;
    }

    /**
     * Geef het volgende (ongelezen) bericht terug, of null als er geen zijn.
     * @param who De betreffende gebruiker
     * @return Het volgende bericht voor deze gebruiker
     */
    public MailItem getNextMailItem(String who)
    {
        Iterator<MailItem> it = items.iterator();
        while(it.hasNext()) {
            MailItem item = it.next();
            if(item.getTo().equals(who)) {
                it.remove();
                return item;
            }
        }
        return null;
    }

    /**
     * Voeg een bericht toe aan de server
     * @param item Het betreffende bericht
     */
    public void post(MailItem item)
    {
        items.add(item);
    }
}
